# Nuru Clock

(Not the clock that Neuro actually uses, that's way more basic.)

Note: This project was made more as a way of putting my understanding of the Neuro Game API into a different language than just TypeScript. Hence why it's basic and also redundant.

## Features

- Gets the current time in any timezone.
- Gets the current time in Unix.

<!--[See the documentation](../docs/) for more.-->

<!-- todo: implement countdown timer, stopwatch(?), alarms -->